# Table of Contents

- [push-webhooks](<./push-webhooks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [PUSH Webhooks](<./PUSH-Webhooks.md>)
  - [Authorization](<./PUSH-Webhooks/Authorization.md>)
  - [Error Handling](<./PUSH-Webhooks/Error-Handling.md>)
  - [Automatic Deactivation](<./PUSH-Webhooks/Automatic-Deactivation.md>)
  - [Callback](<./PUSH-Webhooks/Callback.md>)
